"""
Helper zum Ansteuern des KY-006 Buzzer
"""

import time
from gpiozero import PWMOutputDevice

#Der GPIO Pin wird hier mit der ersten Zahl gesetzt.
buzzer = PWMOutputDevice(6, frequency=500, initial_value=0.0)

def buzz_on():
    """Turn the buzzer on."""
    buzzer.value = 0.5

def buzz_off():
    """Turn the buzzer off."""
    buzzer.value = 0.0

if __name__ == '__main__':
    buzz_on()
    time.sleep(1)
    buzz_off()
    time.sleep(1)




"""
Helper zum auslesen des KY-001 Temperatursensors
Der Code wurde abgewandelt von: https://sensorkit.joy-it.net/de/sensors/ky-001
SPDX-License-Identifier: MIT
"""


import glob
import time
import os

base_dir = '/sys/bus/w1/devices/'
device_folder = glob.glob(base_dir + os.sep + '28*')[0]
device_file = device_folder + '/w1_slave'

def read_temp_raw():
        f = open(device_file, 'r')
        lines = f.readlines()
        f.close()
        return lines

def read_temp():
    lines = read_temp_raw()
    while lines[0].strip()[-3:] != 'YES':
        time.sleep(0.2)
        lines = read_temp_raw()

    equals_pos = lines[1].find('t=')
    if equals_pos != -1:
        temp_string = lines[1][equals_pos + 2:]
        temp_c = float(temp_string) / 1000.0
        return temp_c

#Wenn die Datei direkt ausgeführt wird, wird die Temperatur jede Sekunde ausgegeben.
if __name__ == '__main__':
    while True:
        print("Temperature: {:.2f} C".format(read_temp()))
        time.sleep(1)


"""
Heler zum Ansteuern der LEDs
"""

from gpiozero import LED

# Die entsprechenden GPIO Pins werden hier gesetzt.
red = LED(16)
yellow = LED(20)
green = LED(21)


def set_green(state):
    if state == "on":
        green.on()
    elif state == "off":
        green.off()

def set_yellow(state):
    if state == "on":
        yellow.on()
    elif state == "off":
        yellow.off()

def set_red(state):
    if state == "on":
        red.on()
    elif state == "off":
        red.off()



"""
Dieses Programm wird für die Steuerung des Gesamten Systems genutzt.
"""

import time
import ky001
import ky006
import led

def get_state():
    if ky001.read_temp() <= 25.0:
        return "GREEN"
    elif ky001.read_temp() <= 30.0:
        return "YELLOW"
    elif ky001.read_temp() <= 35.0:
        return "RED"
    elif ky001.read_temp() >= 35.0:
        return "REDPLUS"
    else:
        return "ERROR"
  
def act_on_state(state):
    if state == "GREEN":
        ky006.buzz_off()
        led.set_green("on")
        led.set_yellow("off")
        led.set_red("off")
    elif state == "YELLOW":
        led.set_yellow("on")
        led.set_green("off")
        led.set_red("off")
    elif state == "RED":
        led.set_red("on")
        led.set_green("off")
        led.set_yellow("off")
    elif state == "REDPLUS":
        ky006.buzz_on()
        led.set_red("on")
        led.set_green("off")
        led.set_yellow("off")
    else:
        print("Somethings broken.")



if __name__ == "__main__":
    while True:
        state = get_state()
        print("Current State:", state)
        act_on_state(state)
        time.sleep(1)
